@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 180 $
+# Revision: $Rev: 543 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -37,7 +37,9 @@ from types import ListType
 from Settings import getPreferences
 from AbstractFile import AbstractFileRecord
 from misc import Date2YMD
-from lmcqt import ListViewSort
+
+#from lmcqt import ListViewSort
+from config import cls_ListViewItem
 
 
 #-- preferences ----------------------------------------------------------------
@@ -161,7 +163,7 @@ class ListViewRecord(QListView):
             # all other fields: if no parent exists yet
             if (not self.groupMap.has_key(value)):
                 self.log.debug("Creating parent group %s", value)
-                parent = ListViewSort(self, value, "(1)")
+                parent = cls_ListViewItem(self, value, "(1)")
                 parent.setSelectable(False)
                 self.groupMap[value] = parent
 
@@ -188,7 +190,7 @@ class ListViewRecord(QListView):
             if (not isinstance(r, AbstractFileRecord)):
                 raise(TypeError("Record not instance of AbstractFileRecord"))
             parent = self.parentGroup(r)
-            obj = ListViewSort(parent, *self.compileTitles(r) )
+            obj = cls_ListViewItem(parent, *self.compileTitles(r) )
             obj.setRenameEnabled(0, True)
             self.items[obj] = r
         # keep track of last item added
