@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 376 $
+# Revision: $Rev: 546 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -31,12 +31,14 @@ from os.path import join as fjoin, exists as fexists
 from pprint import pformat, pprint
 from types import DictType, ModuleType
 
+#-- own imports
+import defaults
 
 #-- defaults -------------------------------------------------------------------
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 376 $
+# Revision: $Rev: 546 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -238,7 +240,7 @@ deepcopyOnCopy = %(deepcopyOnCopy)s
 # Currently there is only one default, using transcode's tcprobe command.
 # If transcode is missing a dummy can be used which is only able to
 # automatically retrieve the file size and title: MediaInfo
-# Default: Tcprobe
+# Default: Tcprobe (if available)
 
 mediaInfo = %(mediaInfo)s
 
@@ -258,7 +260,7 @@ autoMountPoint = %(autoMountPoint)s
 # ejectOnUnmount is a modification on the autoMountPoint configuration
 # which causes the removeable media to be ejected when unmounting.
 # This option has no effect when autoMountPoint is set to None.
-# Default: True
+# Default: True (if eject is available)
 
 ejectOnUnmount = %(ejectOnUnmount)s
 
@@ -483,7 +485,7 @@ class _Settings0(dict):
         
         'mediaInfo': None,
         'autoMountPoint': None,
-        'ejectOnUnmount': True,
+        'ejectOnUnmount': defaults.have_eject,
         'autoScanAutoMountOnNew': False,
         'autoScanOnNew': False,
         'autoScriptOnNew': False,
@@ -574,7 +576,8 @@ class _Settings0(dict):
             defs[key] = pformat(self[key])
 
         # class instance 
-        defs['mediaInfo'] = 'MediaInfo.Tcprobe'
+        defs['mediaInfo'] = 'MediaInfo.MediaInfo'
+        if defaults.have_tcprobe: defs['mediaInfo'] = 'MediaInfo.Tcprobe'
 
         # return results
         return defs
