@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 378 $
+# Revision: $Rev: 546 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -24,12 +24,18 @@ import os
 from os.path import join as fjoin, exists as fexists
 
 
-pythondir = "${prefix}/lib/python2.4/site-packages".replace('${prefix}', "/usr/local")
+pythondir = "${prefix}/lib/python2.3/site-packages".replace('${prefix}', "/usr/local")
 installdir = fjoin(pythondir, "lmc")
 
 if (os.getcwd() == "/home/merkosh/Projekte/lmc/src"):
 	installdir = "."
 
-version = "0.12.3"
+version = "0.12.4"
 scriptdir = fjoin(installdir, "scripts")
 resourcedir = fjoin(installdir, "resources")
+
+use_listviewsort = ("yes" == "yes")
+
+have_eject = ("/usr/bin/eject" != "no")
+have_tcprobe = ("/usr/bin/tcprobe" != "no")
+
