@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 407 $
+# Revision: $Rev: 578 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -48,7 +48,7 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("moviefly  $Rev: 407 $ (c) by Uwe Mayer")
+log.info("moviefly  $Rev: 578 $ (c) by Uwe Mayer")
 
 
 #-- own imports --
@@ -490,7 +490,7 @@ class LMCMain(LMCWidgetBase):
         for (cls, _, _) in fileFormats:
             self.log.debug("Autoprobing file format")
             # try opening read-write access
-            try: 
+            try:
                 f = cls(filename, "a+b")
             except IOError, e:
                 # try opening read-only access
@@ -506,7 +506,9 @@ class LMCMain(LMCWidgetBase):
                                         self.tr("Could not open file for write access.\n Opening read-only."),
                                         self.tr("Ok"))
             # class does not support this file format
-            except TypeError: pass
+            except TypeError, e:
+                self.log.error("TypeError trying to open file: %s",filename)
+                raise e
 
         # test if file format was found
         if (f == None):
@@ -1244,7 +1246,7 @@ Synopsis: lmc.py [-h|--help] [<input-file>]
 elif (('-v' in app.argv()[1:]) or ('--version' in app.argv()[1:])):
     print "Moviefly  (c) by Uwe Mayer"
     print "Version:  %s"%version
-    print "Revision: $Rev: 407 $"
+    print "Revision: $Rev: 578 $"
     print 
     sys.exit()
     
