@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 # Author:   $Author: merkosh $
-# Revision: $Rev: 57 $
+# Revision: $Rev: 579 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -32,7 +32,7 @@ use HTTP::Request;
 use HTML::Entities;
 use File::Basename;
 use HTML::TreeBuilder;
-use Math::Round;
+use POSIX qw(ceil);
 
 use LMCTools;
 
@@ -76,7 +76,7 @@ if (substr($ARGV[0], 0,7) eq 'http://') {
 
 
 #-- scan amazon ----------------------------------------------------------------
-$baseURL = 'http://www.amazon.com/';
+$baseURL = 'http://www.amazon.com';
 $searchURL = 'http://www.amazon.com/exec/obidos/search-handle-url/index=dvd&field-title=';
 
 
@@ -93,7 +93,7 @@ if ($title) {
 
   # try to get number of hits to calculate number of consecutive pages
   if ($page =~ /All (\d+) results for/) {
-    $pageCount = round($1 /10);	       # ten hits per page
+    $pageCount = ceil($1 /10);	       # ten hits per page
     $pageCount++ if ($1 % 10 < 5);     # no ceil function in perl (?!)
   }
 
@@ -107,9 +107,9 @@ if ($title) {
     # filter target links
     foreach (@links){
       if ((substr($_->[0], 0, 23) eq "/exec/obidos/tg/detail/") && # URL matches this prefix
-	  ((ref @{$_->[1]->content()}[0] ne "HTML::Element") &&    # link is clear text description
-	   (@{$_->[1]->content()}[0] !~ /buy|in\-store/i)          # link is text and does not contain "buy" and "in-store"
-	   ) 
+	  (ref $_->[1]->content() eq "ARRAY") &&                  # 
+	  (ref @{$_->[1]->content()}[0] ne "HTML::Element") &&    # link is clear text description
+	  (@{$_->[1]->content()}[0] !~ /buy|in\-store/i)          # link is text and does not contain "buy" and "in-store"	    
 	  ) {
 
 	$tlinks{$_->[0]} = $_->[1];		  # target link found
